@@ -82,6 +82,13 @@ sub mysql_enable_utf8
   $self->dbh_attribute_boolean('mysql_enable_utf8', @_)
 }
 
+sub mysql_enable_utf8mb4
+{
+  my($self) = shift;
+  $self->dbh->do('SET NAMES utf8mb4')  if(@_ && $self->has_dbh);
+  $self->dbh_attribute_boolean('mysql_enable_utf8mb4', @_)
+}
+
 sub database_version
 {
   my($self) = shift;
@@ -671,6 +678,14 @@ Returns the value of this attribute in the L<dbh|Rose::DB/dbh>, if one exists, o
 
 See the L<DBD::mysql|DBD::mysql/mysql_enable_utf8> documentation to learn more about this attribute.
 
+=item B<mysql_enable_utf8mb4 [BOOL]>
+
+Get or set the L<mysql_enable_utf8mb4|DBD::mysql/mysql_enable_utf8mb4> database handle attribute.  This is set directly on the L<dbh|Rose::DB/dbh>, if one exists, by executing the SQL C<SET NAMES utf8mb4>.  Otherwise, it will be set when the L<dbh|Rose::DB/dbh> is created.  If no value for this attribute is defined (the default) then it will not be set when the L<dbh|Rose::DB/dbh> is created, deferring instead to whatever default value L<DBD::mysql> chooses.
+
+Returns the value of this attribute in the L<dbh|Rose::DB/dbh>, if one exists, or the value that will be set when the L<dbh|Rose::DB/dbh> is next created.
+
+See the L<DBD::mysql|DBD::mysql/mysql_enable_utf8mb4> documentation to learn more about this attribute.
+
 =item B<mysql_local_infile [STRING]>
 
 Get or set the L<mysql_local_infile|DBD::mysql/mysql_local_infile> database handle attribute.  This is set directly on the L<dbh|Rose::DB/dbh>, if one exists.  Otherwise, it will be set when the L<dbh|Rose::DB/dbh> is created.  If no value for this attribute is defined (the default) then it will not be set when the L<dbh|Rose::DB/dbh> is created, deferring instead to whatever default value L<DBD::mysql> chooses.
